[FFmpeg-cvslog] cosmetics: Fix ATRAC codec name spelling

Diego Biurrun git at videolan.org
Tue Sep 3 15:13:34 CEST 2013


ffmpeg | branch: master | Diego Biurrun <diego at biurrun.de> | Mon Sep  2 20:21:49 2013 +0200| [7df9e693a34c84c698da60426c78140c950f95ed] | committer: Diego Biurrun

cosmetics: Fix ATRAC codec name spelling

> http://git.videolan.org/gitweb.cgi/ffmpeg.git/?a=commit;h=7df9e693a34c84c698da60426c78140c950f95ed
---

 Changelog               |    4 ++--
 doc/general.texi        |    4 ++--
 libavcodec/atrac.c      |    2 +-
 libavcodec/atrac.h      |    4 ++--
 libavcodec/atrac1.c     |    6 +++---
 libavcodec/atrac1data.h |    4 ++--
 libavcodec/atrac3.c     |    8 ++++----
 libavcodec/atrac3data.h |    4 ++--
 libavcodec/codec_desc.c |    6 +++---
 libavformat/omadec.c    |    2 +-
 libavformat/rmdec.c     |    2 +-
 libavformat/spdif.h     |    6 +++---
 12 files changed, 26 insertions(+), 26 deletions(-)

diff --git a/Changelog b/Changelog
index cdbd75d..7e210a7 100644
--- a/Changelog
+++ b/Changelog
@@ -387,7 +387,7 @@ version 0.6:
 - LPCM support in MPEG-TS (HDMV RID as found on Blu-ray disks)
 - WMA Pro decoder
 - Core Audio Format demuxer
-- Atrac1 decoder
+- ATRAC1 decoder
 - MD STUDIO audio demuxer
 - RF64 support in WAV demuxer
 - MPEG-4 Audio Lossless Coding (ALS) decoder
@@ -515,7 +515,7 @@ version 0.5:
 - Interplay C93 demuxer and video decoder
 - Bethsoft VID demuxer and video decoder
 - CRYO APC demuxer
-- Atrac3 decoder
+- ATRAC3 decoder
 - V.Flash PTX decoder
 - RoQ muxer, RoQ audio encoder
 - Renderware TXD demuxer and decoder
diff --git a/doc/general.texi b/doc/general.texi
index dd43e7c..2129ff3 100644
--- a/doc/general.texi
+++ b/doc/general.texi
@@ -721,8 +721,8 @@ following image formats are supported:
     @tab encoding supported through external library libvo-amrwbenc
 @item Apple lossless audio   @tab  X  @tab  X
     @tab QuickTime fourcc 'alac'
- at item Atrac 1                @tab     @tab  X
- at item Atrac 3                @tab     @tab  X
+ at item ATRAC1                 @tab     @tab  X
+ at item ATRAC3                 @tab     @tab  X
 @item Bink Audio             @tab     @tab  X
     @tab Used in Bink and Smacker files in many games.
 @item Delphine Software International CIN audio  @tab     @tab  X
diff --git a/libavcodec/atrac.c b/libavcodec/atrac.c
index ebdbe81..6041a12 100644
--- a/libavcodec/atrac.c
+++ b/libavcodec/atrac.c
@@ -1,5 +1,5 @@
 /*
- * Atrac common functions
+ * ATRAC common functions
  * Copyright (c) 2006-2008 Maxim Poliakovski
  * Copyright (c) 2006-2008 Benjamin Larsson
  *
diff --git a/libavcodec/atrac.h b/libavcodec/atrac.h
index 39fb331..8e9ba59 100644
--- a/libavcodec/atrac.h
+++ b/libavcodec/atrac.h
@@ -1,5 +1,5 @@
 /*
- * Atrac common data
+ * ATRAC common data
  * Copyright (c) 2009 Maxim Poliakovski
  * Copyright (c) 2009 Benjamin Larsson
  *
@@ -22,7 +22,7 @@
 
 /**
  * @file
- * Atrac common header
+ * ATRAC common header
  */
 
 #ifndef AVCODEC_ATRAC_H
diff --git a/libavcodec/atrac1.c b/libavcodec/atrac1.c
index c829898..9a89785 100644
--- a/libavcodec/atrac1.c
+++ b/libavcodec/atrac1.c
@@ -1,5 +1,5 @@
 /*
- * Atrac 1 compatible decoder
+ * ATRAC1 compatible decoder
  * Copyright (c) 2009 Maxim Poliakovski
  * Copyright (c) 2009 Benjamin Larsson
  *
@@ -22,7 +22,7 @@
 
 /**
  * @file
- * Atrac 1 compatible decoder.
+ * ATRAC1 compatible decoder.
  * This decoder handles raw ATRAC1 data and probably SDDS data.
  */
 
@@ -374,6 +374,7 @@ static av_cold int atrac1_decode_init(AVCodecContext *avctx)
 
 AVCodec ff_atrac1_decoder = {
     .name           = "atrac1",
+    .long_name      = NULL_IF_CONFIG_SMALL("ATRAC1 (Adaptive TRansform Acoustic Coding)"),
     .type           = AVMEDIA_TYPE_AUDIO,
     .id             = AV_CODEC_ID_ATRAC1,
     .priv_data_size = sizeof(AT1Ctx),
@@ -381,7 +382,6 @@ AVCodec ff_atrac1_decoder = {
     .close          = atrac1_decode_end,
     .decode         = atrac1_decode_frame,
     .capabilities   = CODEC_CAP_DR1,
-    .long_name      = NULL_IF_CONFIG_SMALL("Atrac 1 (Adaptive TRansform Acoustic Coding)"),
     .sample_fmts    = (const enum AVSampleFormat[]) { AV_SAMPLE_FMT_FLTP,
                                                       AV_SAMPLE_FMT_NONE },
 };
diff --git a/libavcodec/atrac1data.h b/libavcodec/atrac1data.h
index 7d5dbeb..d4b8cd0 100644
--- a/libavcodec/atrac1data.h
+++ b/libavcodec/atrac1data.h
@@ -1,5 +1,5 @@
 /*
- * Atrac 1 compatible decoder data
+ * ATRAC 1 compatible decoder data
  * Copyright (c) 2009 Maxim Poliakovski
  * Copyright (c) 2009 Benjamin Larsson
  *
@@ -22,7 +22,7 @@
 
 /**
  * @file
- * Atrac 1 compatible decoder data
+ * ATRAC1 compatible decoder data
  */
 
 #ifndef AVCODEC_ATRAC1DATA_H
diff --git a/libavcodec/atrac3data.h b/libavcodec/atrac3data.h
index 40518ab..4f5c122 100644
--- a/libavcodec/atrac3data.h
+++ b/libavcodec/atrac3data.h
@@ -1,5 +1,5 @@
 /*
- * Atrac 3 compatible decoder data
+ * ATRAC3 compatible decoder data
  * Copyright (c) 2006-2007 Maxim Poliakovski
  * Copyright (c) 2006-2007 Benjamin Larsson
  *
@@ -22,7 +22,7 @@
 
 /**
  * @file
- * Atrac 3 AKA RealAudio 8 compatible decoder data
+ * ATRAC3 AKA RealAudio 8 compatible decoder data
  */
 
 #ifndef AVCODEC_ATRAC3DATA_H
diff --git a/libavcodec/codec_desc.c b/libavcodec/codec_desc.c
index b91b468..90e4891 100644
--- a/libavcodec/codec_desc.c
+++ b/libavcodec/codec_desc.c
@@ -1920,7 +1920,7 @@ static const AVCodecDescriptor codec_descriptors[] = {
         .id        = AV_CODEC_ID_ATRAC3,
         .type      = AVMEDIA_TYPE_AUDIO,
         .name      = "atrac3",
-        .long_name = NULL_IF_CONFIG_SMALL("Atrac 3 (Adaptive TRansform Acoustic Coding 3)"),
+        .long_name = NULL_IF_CONFIG_SMALL("ATRAC3 (Adaptive TRansform Acoustic Coding 3)"),
         .props     = AV_CODEC_PROP_LOSSY,
     },
 #if FF_API_VOXWARE
@@ -1985,7 +1985,7 @@ static const AVCodecDescriptor codec_descriptors[] = {
         .id        = AV_CODEC_ID_ATRAC3P,
         .type      = AVMEDIA_TYPE_AUDIO,
         .name      = "atrac3p",
-        .long_name = NULL_IF_CONFIG_SMALL("Sony ATRAC3+"),
+        .long_name = NULL_IF_CONFIG_SMALL("ATRAC3+ (Adaptive TRansform Acoustic Coding 3+)"),
         .props     = AV_CODEC_PROP_LOSSY,
     },
     {
@@ -2034,7 +2034,7 @@ static const AVCodecDescriptor codec_descriptors[] = {
         .id        = AV_CODEC_ID_ATRAC1,
         .type      = AVMEDIA_TYPE_AUDIO,
         .name      = "atrac1",
-        .long_name = NULL_IF_CONFIG_SMALL("Atrac 1 (Adaptive TRansform Acoustic Coding)"),
+        .long_name = NULL_IF_CONFIG_SMALL("ATRAC1 (Adaptive TRansform Acoustic Coding)"),
         .props     = AV_CODEC_PROP_LOSSY,
     },
     {
diff --git a/libavformat/omadec.c b/libavformat/omadec.c
index 1d7fc91..e491782 100644
--- a/libavformat/omadec.c
+++ b/libavformat/omadec.c
@@ -342,7 +342,7 @@ static int oma_read_header(AVFormatContext *s)
         st->codec->sample_rate = samplerate;
         st->codec->bit_rate    = st->codec->sample_rate * framesize * 8 / 1024;
 
-        /* fake the atrac3 extradata
+        /* fake the ATRAC3 extradata
          * (wav format, makes stream copy to wav work) */
         st->codec->extradata_size = 14;
         edata = av_mallocz(14 + FF_INPUT_BUFFER_PADDING_SIZE);
diff --git a/libavformat/rmdec.c b/libavformat/rmdec.c
index 83cf1b0..afa37de 100644
--- a/libavformat/rmdec.c
+++ b/libavformat/rmdec.c
@@ -29,7 +29,7 @@
 #include "rmsipr.h"
 #include "rm.h"
 
-#define DEINT_ID_GENR MKTAG('g', 'e', 'n', 'r') ///< interleaving for Cooker/Atrac
+#define DEINT_ID_GENR MKTAG('g', 'e', 'n', 'r') ///< interleaving for Cooker/ATRAC
 #define DEINT_ID_INT0 MKTAG('I', 'n', 't', '0') ///< no interleaving needed
 #define DEINT_ID_INT4 MKTAG('I', 'n', 't', '4') ///< interleaving for 28.8
 #define DEINT_ID_SIPR MKTAG('s', 'i', 'p', 'r') ///< interleaving for Sipro
diff --git a/libavformat/spdif.h b/libavformat/spdif.h
index b2a6b63..f5b15eb 100644
--- a/libavformat/spdif.h
+++ b/libavformat/spdif.h
@@ -40,9 +40,9 @@ enum IEC61937DataType {
     IEC61937_DTS1               = 0x0B,          ///< DTS type I   (512 samples)
     IEC61937_DTS2               = 0x0C,          ///< DTS type II  (1024 samples)
     IEC61937_DTS3               = 0x0D,          ///< DTS type III (2048 samples)
-    IEC61937_ATRAC              = 0x0E,          ///< Atrac data
-    IEC61937_ATRAC3             = 0x0F,          ///< Atrac 3 data
-    IEC61937_ATRACX             = 0x10,          ///< Atrac 3 plus data
+    IEC61937_ATRAC              = 0x0E,          ///< ATRAC data
+    IEC61937_ATRAC3             = 0x0F,          ///< ATRAC3 data
+    IEC61937_ATRACX             = 0x10,          ///< ATRAC3+ data
     IEC61937_DTSHD              = 0x11,          ///< DTS HD data
     IEC61937_WMAPRO             = 0x12,          ///< WMA 9 Professional data
     IEC61937_MPEG2_AAC_LSF_2048 = 0x13,          ///< MPEG-2 AAC ADTS half-rate low sampling frequency



More information about the ffmpeg-cvslog mailing list
diff --git a/libavcodec/atrac3.c b/libavcodec/atrac3.c
index 6a8fae7..1cb7b2b 100644
--- a/libavcodec/atrac3.c
+++ b/libavcodec/atrac3.c
@@ -1,5 +1,5 @@
 /*
- * Atrac 3 compatible decoder
+ * ATRAC3 compatible decoder
  * Copyright (c) 2006-2008 Maxim Poliakovski
  * Copyright (c) 2006-2008 Benjamin Larsson
  *
@@ -22,10 +22,10 @@
 
 /**
  * @file
- * Atrac 3 compatible decoder.
+ * ATRAC3 compatible decoder.
  * This decoder handles Sony's ATRAC3 data.
  *
  * Container formats used to store atrac 3 data:
  * RealMedia (.rm), RIFF WAV (.wav, .at3), Sony OpenMG (.oma, .aa3).
  *
  * To use this decoder, a calling application must supply the extradata
@@ -996,6 +996,7 @@ static av_cold int atrac3_decode_init(AVCodecContext *avctx)
 
 AVCodec ff_atrac3_decoder = {
     .name             = "atrac3",
+    .long_name        = NULL_IF_CONFIG_SMALL("ATRAC3 (Adaptive TRansform Acoustic Coding 3)"),
     .type             = AVMEDIA_TYPE_AUDIO,
     .id               = AV_CODEC_ID_ATRAC3,
     .priv_data_size   = sizeof(ATRAC3Context),
@@ -1004,7 +1005,6 @@ AVCodec ff_atrac3_decoder = {
     .close            = atrac3_decode_close,
     .decode           = atrac3_decode_frame,
     .capabilities     = CODEC_CAP_SUBFRAMES | CODEC_CAP_DR1,
-    .long_name        = NULL_IF_CONFIG_SMALL("Atrac 3 (Adaptive TRansform Acoustic Coding 3)"),
     .sample_fmts      = (const enum AVSampleFormat[]) { AV_SAMPLE_FMT_FLTP,
                                                         AV_SAMPLE_FMT_NONE },
 };
@@ -22,10 +22,10 @@
  * This decoder handles Sony's ATRAC3 data.
  *
- * Container formats used to store atrac 3 data:
+ * Container formats used to store ATRAC3 data:
  * RealMedia (.rm), RIFF WAV (.wav, .at3), Sony OpenMG (.oma, .aa3).
  *